/*
 * This file is part of ReporteRs
 * Copyright (c) 2014, David Gohel All rights reserved.
 * This program is licensed under the GNU GENERAL PUBLIC LICENSE V3.
 * You may obtain a copy of the License at :
 * http://www.gnu.org/licenses/gpl.html
 */

package org.lysis.reporters.docs;

import java.io.File;
import java.util.HashMap;
import java.util.Iterator;

import javax.xml.bind.JAXBException;

import org.docx4j.openpackaging.exceptions.Docx4JException;
import org.docx4j.openpackaging.exceptions.InvalidFormatException;
import org.docx4j.openpackaging.packages.PresentationMLPackage;
import org.docx4j.openpackaging.parts.Part;
import org.docx4j.openpackaging.parts.PartName;
import org.docx4j.openpackaging.parts.PresentationML.MainPresentationPart;
import org.docx4j.openpackaging.parts.PresentationML.SlideLayoutPart;
import org.docx4j.openpackaging.parts.PresentationML.SlidePart;
import org.docx4j.relationships.Relationship;
import org.lysis.reporters.lists.NumberingDefinition;
import org.lysis.reporters.pptx4r.elements.template.LayoutDescription;
import org.lysis.reporters.pptx4r.elements.template.MasterLayoutProperties;
import org.lysis.reporters.pptx4r.tools.DocExplorer;
import org.pptx4j.pml.Presentation.SldIdLst;


public class pptx4R {

	public static int NO_ERROR = 0;
	public static int READDOC_ERROR = 1;
	public static int LOADDOC_ERROR = 2;
	public static int LAYOUT_ERROR = 3;
	public static int SAVE_ERROR = 4;
	public static int PARTNAME_ERROR = 5;
	public static int SLIDECREATION_ERROR = 6;
	// public static int slidedimensions_error = 7;
	public static int UNDEFINED_ERROR = -1;

	private PresentationMLPackage baseDocument;
	private int slideIndex;
	private MasterLayoutProperties masterLayoutProperties;
	private HashMap<String, LayoutDescription> layoutList;
	private int width, height;
	private NumberingDefinition numberingDefinition;
	
//	private boolean restartNumbering = false;
	public pptx4R() {
		slideIndex = 0;
	}

	private int getNewUIDSlide() {
		slideIndex++;
		return slideIndex;
	}

//	public void setRestartNumbering(boolean val){
//		restartNumbering = val;
//	}
//	
//	public boolean getRestartNumbering(){
//		return restartNumbering;
//	}
	
	public int[] readSlideDimensions( ){
		PartName presentationPartname = null;
		int[] dims = new int[2];
		dims[0] = dims[1] = -1;
		
		try {
			presentationPartname = new PartName("/ppt/presentation.xml");
			MainPresentationPart mainPresentationPart = (MainPresentationPart) baseDocument.getParts().getParts().get(presentationPartname);
			dims[0] = mainPresentationPart.getJaxbElement().getSldSz().getCx();
			dims[1] = mainPresentationPart.getJaxbElement().getSldSz().getCy();
		} catch (InvalidFormatException e) {
			System.err.println("unable to read presentation.xml.");
		}
		return dims;
	}
	
	public void setNumberingDefinition(NumberingDefinition nd) {
		numberingDefinition = nd;
	}
	
	public NumberingDefinition getNumberingDefinition() {
		return numberingDefinition ;
	}
	
	public int setBaseDocument(String baseDocFileName) {
		File baseDocFile = null;

		try {
			baseDocFile = new File(baseDocFileName);
		} catch (Exception e) {
			return READDOC_ERROR;
		}
		try {
			baseDocument = PresentationMLPackage.load(baseDocFile);
		} catch (Docx4JException e) {
			return LOADDOC_ERROR;
		}
		
		// How much existing slides
		slideIndex = DocExplorer.countExistingSlides(baseDocument);
		try {
			layoutList = new HashMap<String, LayoutDescription>();
			layoutList = DocExplorer.browseLayouts(baseDocument);// read available layouts
			masterLayoutProperties = new MasterLayoutProperties();
			masterLayoutProperties.feed(baseDocument);
		} catch (InvalidFormatException e) {
			System.err.println("LAYOUT_ERROR");
			return LAYOUT_ERROR;

		}
		return NO_ERROR;
	}

	public int writePptxToStream(String target) throws Exception {
		File f = new File(target);
		try {
			baseDocument.save(f);
			return NO_ERROR;
		} catch (Docx4JException e) {
			return SAVE_ERROR;
		}
	}

	public String[] getStyleNames() {
		String[] stylenames = new String[layoutList.size()];
		int i = 0;
		for (Iterator<String> it1 = layoutList.keySet().iterator(); it1
				.hasNext();) {
			stylenames[i] = it1.next();
			i++;
		}
		return stylenames;
	}

	public int getSlideNumber() {
		return slideIndex;
	}

	public SlidePart getNewSlide(String layoutName) throws Exception {
		
		if( !layoutList.containsKey(layoutName)) 
			throw new Exception("No layout named " + layoutName );

		PartName presentationPartname = null;
		PartName LayoutPartname = null;
		PartName slidePartname = null;

		SlidePart slidePart = null;
		int UIDSlide = getNewUIDSlide();
		try {
			presentationPartname = new PartName("/ppt/presentation.xml");
			LayoutPartname = new PartName(layoutList.get(layoutName).getXMLFilename());
			slidePartname = new PartName("/ppt/slides/slide" + UIDSlide
					+ ".xml");
		} catch (InvalidFormatException e) {
			System.err.println("unable to create one of the partnames.");
		}

		MainPresentationPart mainPresentationPart = (MainPresentationPart) baseDocument
				.getParts().getParts().get(presentationPartname);
		SlideLayoutPart layoutPart = (SlideLayoutPart) baseDocument.getParts()
				.getParts().get(LayoutPartname);
		
		width= mainPresentationPart.getJaxbElement().getSldSz().getCx();
		height= mainPresentationPart.getJaxbElement().getSldSz().getCy();
		
		try {
			if (slideIndex < 2) {
				mainPresentationPart.getJaxbElement().setSldIdLst(
						new SldIdLst());
			}

			// OK, now we can create a slide
			slidePart = new SlidePart(slidePartname);
			slidePart.setContents( SlidePart.createSld() );		
			mainPresentationPart.addSlide(slidePart);
			
			// Slide layout part
			slidePart.addTargetPart(layoutPart);

		} catch (InvalidFormatException e) {
			System.err.println("unable to create a new slide.");
		} catch (JAXBException e) {
			System.err.println("unable to create a new slide.");
		}

		return slidePart;
	}
	
	
	public SlidePart getAndReInitExistingSlide(String layoutName, int UIDSlide) throws Exception {
		
		if( slideIndex < 1 )
			throw new Exception("Slide cannot be replaced as there is no slide in the template");
		if( slideIndex < UIDSlide )
			throw new Exception( "Slide number " + UIDSlide + " cannot be replaced as it does not exists.");
		
		PartName presentationPartname = null;
		PartName LayoutPartname = null;
		PartName slidePartname = null;

		MainPresentationPart presentation = baseDocument.getMainPresentationPart();
		try {
			presentationPartname = new PartName("/ppt/presentation.xml");
			LayoutPartname = new PartName(layoutList.get(layoutName).getXMLFilename());
			slidePartname = new PartName("/ppt/slides/slide" + UIDSlide
					+ ".xml");
		} catch (InvalidFormatException e) {
			System.err.println("unable to create one of the partnames.");
		}

		MainPresentationPart mainPresentationPart = (MainPresentationPart) baseDocument
				.getParts().getParts().get(presentationPartname);
		SlideLayoutPart layoutPart = (SlideLayoutPart) baseDocument.getParts()
				.getParts().get(LayoutPartname);
		
		width= mainPresentationPart.getJaxbElement().getSldSz().getCx();
		height= mainPresentationPart.getJaxbElement().getSldSz().getCy();
		
		Part part = baseDocument.getParts().get(slidePartname);
		Relationship rel = part.getSourceRelationships().get(0);
		presentation.removeSlide(rel);	
		
		SlidePart slidePart = null;
		try {
			if (slideIndex < 2) {
				mainPresentationPart.getJaxbElement().setSldIdLst(
						new SldIdLst());
			}
			
			// OK, now we can create a slide
			slidePart  = new SlidePart(slidePartname);
			slidePart.setContents( SlidePart.createSld() );		
			mainPresentationPart.addSlide(UIDSlide-1, slidePart);
			
			// Slide layout part
			slidePart.addTargetPart(layoutPart);

		} catch (InvalidFormatException e) {
			System.err.println("unable to create a new slide.");
		} catch (JAXBException e) {
			System.err.println("unable to create a new slide.");
		}

		return slidePart;
	}
	
	
   public int getDocWidth() {
		return width;
	}
   
	public int getDocHeight() {
		return height;
	}
			
	public LayoutDescription getLayoutProperties(String slideName) {
		LayoutDescription ld = layoutList.get(slideName);
		ld.fixMissingXfrm(masterLayoutProperties);
		return ld;
	}
	public MasterLayoutProperties getMasterLayoutProperties() {
		return masterLayoutProperties;
	}

	protected PresentationMLPackage getBaseDocument() {
		return baseDocument;
	}
	
//	static private String STR = "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"yes\"?>\n" +
//			"<p:graphicFrame xmlns:a=\"http://schemas.openxmlformats.org/drawingml/2006/main\" xmlns:r=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships\" xmlns:p=\"http://schemas.openxmlformats.org/presentationml/2006/main\"><p:nvGraphicFramePr><p:cNvPr id=\"2\" name=\"nvGraphicFrame 2\"/><p:cNvGraphicFramePr><a:graphicFrameLocks noGrp=\"true\"/></p:cNvGraphicFramePr><p:nvPr/></p:nvGraphicFramePr><p:xfrm rot=\"0\"><a:off x=\"914400\" y=\"914400\"/></p:xfrm><a:graphic><a:graphicData uri=\"http://schemas.openxmlformats.org/drawingml/2006/table\"><a:tbl><a:tblPr/><a:tblGrid><a:gridCol w=\"748543\"/><a:gridCol w=\"684733\"/><a:gridCol w=\"713197\"/><a:gridCol w=\"649387\"/><a:gridCol w=\"451817\"/></a:tblGrid><a:tr h=\"90884\"><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>Sepal.Length</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>Sepal.Width</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>Petal.Length</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>Petal.Width</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>Species</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc></a:tr><a:tr h=\"90884\"><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>5.1</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>3.5</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>1.4</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>0.2</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>setosa</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc></a:tr></a:tbl></a:graphicData></a:graphic></p:graphicFrame>";
	static private String STR = "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"yes\"?>\n<p:graphicFrame xmlns:a=\"http://schemas.openxmlformats.org/drawingml/2006/main\" xmlns:r=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships\" xmlns:p=\"http://schemas.openxmlformats.org/presentationml/2006/main\" ><p:nvGraphicFramePr><p:cNvPr id=\"2\" name=\"nvGraphicFrame 2\"/><p:cNvGraphicFramePr><a:graphicFrameLocks noGrp=\"true\"/></p:cNvGraphicFramePr><p:nvPr/></p:nvGraphicFramePr><p:xfrm rot=\"0\"><a:off x=\"914400\" y=\"914400\"/></p:xfrm><a:graphic><a:graphicData uri=\"http://schemas.openxmlformats.org/drawingml/2006/table\"><a:tbl><a:tblPr/><a:tblGrid><a:gridCol w=\"748543\"/><a:gridCol w=\"684733\"/><a:gridCol w=\"713197\"/><a:gridCol w=\"649387\"/><a:gridCol w=\"451817\"/></a:tblGrid><a:tr h=\"90884\"><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>Sepal.Length</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>Sepal.Width</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>Petal.Length</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>Petal.Width</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>Species</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc></a:tr><a:tr h=\"90884\"><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>5.1</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>3.5</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>1.4</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>0.2</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>setosa</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc></a:tr><a:tr h=\"90884\"><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>4.9</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>3</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>1.4</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>0.2</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>setosa</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc></a:tr><a:tr h=\"90884\"><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>4.7</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>3.2</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>1.3</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>0.2</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>setosa</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc></a:tr><a:tr h=\"90884\"><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>4.6</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>3.1</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>1.5</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>0.2</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>setosa</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc></a:tr><a:tr h=\"90884\"><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>5</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>3.6</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>1.4</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>0.2</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc><a:tc><a:txBody><a:bodyPr/><a:lstStyle/><a:p><a:pPr algn=\"r\" marL=\"25400\" marR=\"25400\"><a:spcBef><a:spcPts val=\"200\" /></a:spcBef><a:spcAft><a:spcPts val=\"200\" /></a:spcAft><a:buNone/></a:pPr><a:r><a:rPr sz=\"1000\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:latin typeface=\"Arial\"/><a:cs typeface=\"Arial\"/></a:rPr><a:t>setosa</a:t></a:r></a:p></a:txBody><a:tcPr anchor=\"ctr\" marB=\"0\" marT=\"0\" marR=\"0\" marL=\"0\"><a:lnL algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnL><a:lnR algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnR><a:lnT algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnT><a:lnB algn=\"ctr\" cmpd=\"sng\" cap=\"flat\" w=\"12700\"><a:solidFill><a:srgbClr val=\"000000\"><a:alpha val=\"100000\"/></a:srgbClr></a:solidFill><a:prstDash val=\"solid\"/></a:lnB></a:tcPr></a:tc></a:tr></a:tbl></a:graphicData></a:graphic></p:graphicFrame>";

	public static void main(String[] argv) throws Exception{
		pptx4R doc = new pptx4R();
		doc.setBaseDocument("/Users/davidgohel/Downloads/template.pptx");
		SlidePart sp = doc.getNewSlide("custom");
		LayoutDescription lp = doc.getLayoutProperties("custom");
		SlideContent sc = new SlideContent(sp, doc, lp);
		
		
		sc.add_xml_flextable(STR);
		
		doc.writePptxToStream("/Users/davidgohel/Downloads/out.pptx");
		
	}
	
}
